@@ -48,6 +48,9 @@ from .lazypeertube import LazypeertubeCommand
 from .lazysoundcloud import LazysoundcloudCommand
 from .lazyyahoovideo import LazyyahoovideoCommand
 from .lazyyoutube import LazyyoutubeCommand
+from .funkwhalealbum import FunkwhalealbumCommand
+from .lazyfunkwhalealbum import LazyfunkwhalealbumCommand
+from .matchmaking import MatchmakingCommand
 
 # Enter the commands of your Pack here!
 available_commands = [
@@ -100,6 +103,9 @@ available_commands = [
     LazysoundcloudCommand,
     LazyyahoovideoCommand,
     LazyyoutubeCommand,
+    FunkwhalealbumCommand,
+    LazyfunkwhalealbumCommand,
+    MatchmakingCommand,
 ]
 
 # Don't change this, it should automatically generate __all__
