@@ -7,6 +7,4 @@ class MMChoice(enum.Enum):
     LATE_SHORT = "🕐"
     LATE_MEDIUM = "🕒"
     LATE_LONG = "🕗"
-    NO_TIME = "🔴"
-    NO_INTEREST = "❌"
-    NO_TECH = "❗️"
+    NO = "❌"
